[−][src]Crate cloudevents
Modules
| event |
Structs
| Event | Data structure that represents a CloudEvent.
It provides methods to get the attributes through |
| event |
| Event | Data structure that represents a CloudEvent.
It provides methods to get the attributes through |