Module cloudevents::binding
source · Expand description
Provides protocol binding implementations for crate::Event.
Modules
- actix
actixThis module integrates the cloudevents-sdk with Actix web to easily send and receive CloudEvents. - axum
axumThis module integrates the cloudevents-sdk with Axum web service framework to easily send and receive CloudEvents. - http
http-bindingoractixorwarporreqwestoraxumorpoem - nats
natsThis module provides bindings between cloudevents-sdk and nats - poem
poemThis module integrates the cloudevents-sdk with Poem to easily send and receive CloudEvents. - rdkafka
rdkafkaThis library provides Kafka protocol bindings for CloudEvents using the rust-rdkafka library. - reqwest
reqwestThis module integrates the cloudevents-sdk with reqwest to easily send and receive CloudEvents. - warp
warpThis module integrates the cloudevents-sdk with Warp web service framework to easily send and receive CloudEvents.