pub trait Builder<R> {
    // Required methods
    fn header(&mut self, key: &str, value: HeaderValue);
    fn body(&mut self, bytes: Vec<u8>) -> Result<R>;
    fn finish(&mut self) -> Result<R>;
}
Available on crate features http-binding or actix or warp or reqwest or axum or poem only.

Required Methods

source

fn header(&mut self, key: &str, value: HeaderValue)

source

fn body(&mut self, bytes: Vec<u8>) -> Result<R>

source

fn finish(&mut self) -> Result<R>

Implementations on Foreign Types

source

impl Builder<HttpResponse<BoxBody>> for HttpResponseBuilder

Available on crate feature actix only.
source

fn header(&mut self, key: &str, value: HeaderValue)

Available on crate features http-binding or actix or warp or reqwest or axum or poem only.
source

fn body(&mut self, bytes: Vec<u8>) -> Result<HttpResponse>

Available on crate features http-binding or actix or warp or reqwest or axum or poem only.
source

fn finish(&mut self) -> Result<HttpResponse>

Available on crate features http-binding or actix or warp or reqwest or axum or poem only.

Implementors