pub struct NatsCloudEvent {
pub payload: Vec<u8>,
}
Available on crate feature nats only.
Helper struct containing text data bytes of JSON serialized Event
Implements AsRef so it can be directly passed to nats::Connection methods as payload.
Converts this type into a shared reference of the (usually inferred) input type.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.