MessageExt

Trait MessageExt 

pub trait MessageExt: Sealed {
    // Required method
    fn to_event(&self) -> Result<Event>;
}
Available on crate feature rdkafka only.
Extension Trait for Message which acts as a wrapper for the function record_to_event().

This trait is sealed and cannot be implemented for types outside of this crate.

Required Methods

fn to_event(&self) -> Result<Event>

Generates Event from BorrowedMessage.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl MessageExt for BorrowedMessage<'_>

Source

impl MessageExt for OwnedMessage

Implementors