Enum cloudevents::event::Attributes [−][src]
pub enum Attributes {
V03(AttributesV03),
V10(AttributesV10),
}Expand description
Union type representing one of the possible context attributes structs
Variants
V03(AttributesV03)V10(AttributesV10)Trait Implementations
Set the datacontenttype. Returns the previous value. Read more
Set the dataschema. Returns the previous value. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.