pub trait BinaryDeserializerwhere
    Self: Sized,{
    // Required method
    fn deserialize_binary<R: Sized, V: BinarySerializer<R>>(
        self,
        serializer: V
    ) -> Result<R>;

    // Provided method
    fn into_event(self) -> Result<Event> { ... }
}
Deserializer trait for a Message that can be encoded as binary mode.

Required Methods

source

fn deserialize_binary<R: Sized, V: BinarySerializer<R>>( self, serializer: V ) -> Result<R>

Deserialize the message to BinarySerializer.

Provided Methods

source

fn into_event(self) -> Result<Event>

Convert this Message to Event.

Implementors

source

impl BinaryDeserializer for ConsumerRecordDeserializer

Available on crate feature rdkafka only.
source

impl BinaryDeserializer for Event

source

impl<'a, T: Headers<'a>> BinaryDeserializer for Deserializer<'a, T>

Available on crate features http-binding or actix or warp or reqwest or axum or poem only.