pub trait StructuredDeserializerwhere
    Self: Sized,{
    // Required method
    fn deserialize_structured<R: Sized, V: StructuredSerializer<R>>(
        self,
        serializer: V
    ) -> Result<R>;

    // Provided method
    fn into_event(self) -> Result<Event> { ... }
}
Deserializer trait for a Message that can be encoded as structured mode.

Required Methods

source

fn deserialize_structured<R: Sized, V: StructuredSerializer<R>>( self, serializer: V ) -> Result<R>

Deserialize the message to StructuredSerializer.

Provided Methods

source

fn into_event(self) -> Result<Event>

Convert this Message to Event.

Implementations on Foreign Types

source

impl StructuredDeserializer for Message

Available on crate feature nats only.
source

fn deserialize_structured<R: Sized, V: StructuredSerializer<R>>( self, serializer: V ) -> Result<R>

Implementors

source

impl StructuredDeserializer for ConsumerRecordDeserializer

Available on crate feature rdkafka only.
source

impl StructuredDeserializer for Event

source

impl<'a, T: Headers<'a>> StructuredDeserializer for Deserializer<'a, T>

Available on crate features http-binding or actix or warp or reqwest or axum or poem only.