pub trait HttpRequestExt: Sealed {
// Required method
fn to_event<'life0, 'async_trait>(
&'life0 self,
payload: Payload,
) -> Pin<Box<dyn Future<Output = Result<Event, Error>> + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Available on crate feature
actix only.Expand description
Extension Trait for HttpRequest which acts as a wrapper for the function request_to_event().
This trait is sealed and cannot be implemented for types outside of this crate.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".