pub trait HttpResponseBuilderExt: Sealed {
// Required method
fn event(self, event: Event) -> Result<HttpResponse, Error>;
}Available on crate feature
actix only.Expand description
Extension Trait for HttpResponseBuilder which acts as a wrapper for the function event_to_response().
This trait is sealed and cannot be implemented for types outside of this crate.
Required Methods
Sourcefn event(self, event: Event) -> Result<HttpResponse, Error>
fn event(self, event: Event) -> Result<HttpResponse, Error>
Fill this HttpResponseBuilder with an Event.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".