Module cloudevents::binding::http
source · Available on crate features
http-binding or actix or warp or reqwest or axum or poem only.Re-exports
pub use builder::Builder;
Modules
Structs
Statics
Traits
- Any http library should be able to use the
to_eventfunction with an implementation of this trait.
Functions
- Turn a pile of HTTP headers and a body into a CloudEvent