pub trait MessageExt: Sealed {
// Required method
fn to_event(&self) -> Result<Event>;
}Available on crate feature
rdkafka only.Expand description
Extension Trait for Message which acts as a wrapper for the function record_to_event().
This trait is sealed and cannot be implemented for types outside of this crate.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".