Trait cloudevents::message::BinaryDeserializer
source · pub trait BinaryDeserializerwhere
Self: Sized,{
// Required method
fn deserialize_binary<R: Sized, V: BinarySerializer<R>>(
self,
serializer: V
) -> Result<R>;
// Provided method
fn into_event(self) -> Result<Event> { ... }
}Expand description
Deserializer trait for a Message that can be encoded as binary mode.
Required Methods
sourcefn deserialize_binary<R: Sized, V: BinarySerializer<R>>(
self,
serializer: V
) -> Result<R>
fn deserialize_binary<R: Sized, V: BinarySerializer<R>>( self, serializer: V ) -> Result<R>
Deserialize the message to BinarySerializer.
Provided Methods
sourcefn into_event(self) -> Result<Event>
fn into_event(self) -> Result<Event>
Convert this Message to Event.
Implementors
impl BinaryDeserializer for ConsumerRecordDeserializer
Available on crate feature
rdkafka only.impl BinaryDeserializer for Event
impl<'a, T: Headers<'a>> BinaryDeserializer for Deserializer<'a, T>
Available on crate features
http-binding or actix or warp or reqwest or axum or poem only.